# SpringSaLaDpy

## What is SpringSaLaDpy

SpringSaLaDpy provides a lightweight command-line interface for the modeling and simulation software SpringSaLaD (Springs, Sites, and Langevin Dynamics) for spatial, stochastic, particle-based modeling of biomolecules accounting for their volumes and diffusions. SpringSaLaDpy streamlines the execution of multiple SpringSalad simulations over the specified parameter sets. It provides extended analysis and visualization of spatial simulation results, such as composition and spatial distribution of molecules. Importantly, being an open architecture it enables Python-based customization of SpringSalad inputs and outputs.

## Usage

Install this package by running the following command in a terminal window: pip install springsaladpy

## Documentation

Visit the companion demo repository (https://github.com/SpringSaLaDpy/demo) for examples and detailed explanations of every function.